# ctdGAN
A Generative Adversarial Network for synthesizing artificial tabular data

ctdGAN is a Conditional Generative Adversarial Network for alleviating class imbalance in tabular datasets. The model is based on an initial space partitioning step that assigns cluster labels to the input samples.
These labels are used to synthesize samples via a probabilistic sampling mechanism. ctdGAN optimizes a loss function that is sensitive to both cluster and class mis-predictions, rendering the model capable of
generating samples in subspaces that resemble those of the original data distribution.

**Licence:** Apache License, 2.0 (Apache-2.0)
